import gobject, rox, os

from traylib import *
from traylib.menu_icon import MenuIcon

icon_theme.append_search_path(os.path.join(rox.app_dir, 'icons'))

class MainIcon(MenuIcon):

    def __init__(self, tray, icon_config, tray_config):
        MenuIcon.__init__(self, tray, icon_config, tray_config)
        screen.connect("showing-desktop-changed", self.__showing_desktop_changed)
        self.connect("destroy", self.__destroy)
        self.__icon_theme_changed_handler = icon_theme.connect("changed", self.__theme_changed)
        tray.win_config.add_configurable(self)

    def __theme_changed(self, icon_theme):
        self.update_icon()
        
    def __destroy(self, widget):
        icon_theme.disconnect(self.__icon_theme_changed_handler)

    def __showing_desktop_changed(self, screen):
        self.update_icon()
        self.update_tooltip()
        
    def update_option_all_workspaces(self):
        self.update_tooltip()

    def click(self, time):
        screen.toggle_showing_desktop(not screen.get_showing_desktop())

    def mouse_wheel_up(self, time):
        self.tray.win_config.all_workspaces = True

    def mouse_wheel_down(self, time):
        self.tray.win_config.all_workspaces = False

    def make_icon(self):
        if screen.get_showing_desktop():
            icon_name = "preferences-system-windows"
        else:
            icon_name = "user-desktop"
        icon_info = icon_theme.lookup_icon(icon_name, self.size, 0)
        assert icon_info
        icon_path = icon_info.get_filename()
        return gtk.gdk.pixbuf_new_from_file(icon_path)

    def make_tooltip(self):
        if screen.get_showing_desktop():
            s = _("Click to show windows.\n")
        else:
            s = _("Click to show the desktop.\n")
        if self.tray.win_config.all_workspaces:
            s += _("Scroll down to only show windows of this workspace.")
        else:
            s += _("Scroll up to show windows of all workspaces.")
        #s += _("Right click will open the TaskTray menu.")
        return s
